@@ -33,7 +33,7 @@
 #'
 #' # styler: off
 #' matched <- tribble(
-#'   ~sector, ~sector_ald,  ~score, ~id_loan,                ~level,
+#'   ~sector, ~sector_abcd,  ~score, ~id_loan,                ~level,
 #'    "coal",      "coal",       1,     "aa",     "ultimate_parent",
 #'    "coal",      "coal",       1,     "aa",    "direct_loantaker",
 #'    "coal",      "coal",       1,     "bb", "intermediate_parent",
@@ -61,9 +61,32 @@ prioritize <- function(data, priority = NULL) {
     return(data)
   }
 
+  if (all(c("sector_ald", "sector_abcd") %in% names(data))) {
+
+    rlang::abort(
+      "too_many_sectors",
+      message = glue(
+        "Column `sector_ald` is deprecated as of r2dii.match 0.1.0, please use
+        `sector_abcd` instead."
+      )
+    )
+
+  } else if ("sector_ald" %in% names(data)) {
+
+    rlang::warn(
+      "deprecated_name",
+      message = glue(
+        "Column `sector_ald` is deprecated as of r2dii.match 0.1.0, please use
+        `sector_abcd` instead."
+      )
+    )
+
+    data <- dplyr::rename(data, sector_abcd = .data$sector_ald)
+  }
+
   data %>%
     check_crucial_names(
-      c("id_loan", "level", "score", "sector", "sector_ald")
+      c("id_loan", "level", "score", "sector", "sector_abcd")
     ) %>%
     check_duplicated_score1()
 
@@ -73,7 +96,7 @@ prioritize <- function(data, priority = NULL) {
   perfect_matches <- filter(ungroup(data), .data$score == 1L)
 
   out <- perfect_matches %>%
-    group_by(.data$id_loan, .data$sector, .data$sector_ald) %>%
+    group_by(.data$id_loan, .data$sector, .data$sector_abcd) %>%
     prioritize_at(.at = "level", priority = priority) %>%
     ungroup()
 
@@ -100,7 +123,7 @@ check_duplicated_score1 <- function(data) {
     message = glue(
       "`data` where `score` is `1` must be unique by `id_loan` by `level`.
      Duplicated rows: {duplicated_rows}.
-     Have you ensured that only one ald-name per loanbook-name is set to `1`?"
+     Have you ensured that only one abcd-name per loanbook-name is set to `1`?"
     )
   )
 }
