@@ -17,13 +17,12 @@ test_that("w/ non-NA only at intermediate level yields matches at intermediate
     sector_classification_direct_loantaker = 3511,
   )
 
-  ald <- tibble(
+  abcd <- tibble(
     name_company = c("nanco hosiery mills", "standard solar inc"),
-    sector = c("power", "power"),
-    alias_ald = c("nancohosierymills", "standardsolar inc")
+    sector = c("power", "power")
   )
 
-  out <- match_name(lbk, ald)
+  out <- match_name(lbk, abcd)
   expect_equal(out$level, "intermediate_parent_999")
 })
 
@@ -37,18 +36,17 @@ test_that("w/ missing values at all levels outputs 0-row", {
     sector_classification_direct_loantaker = 291,
   )
 
-  ald <- tibble(
+  abcd <- tibble(
     name_company = "any",
-    sector = "power",
-    alias_ald = "any",
+    sector = "power"
   )
 
-  expect_warning(out <- match_name(lbk, ald), "no match")
+  expect_warning(out <- match_name(lbk, abcd), "no match")
   expect_equal(nrow(out), 0L)
 })
 
-test_that("w/ 1 lbk row matching 1 ald company in 2 sectors outputs 2 rows", {
-  sector_ald <- c("automotive", "shipping")
+test_that("w/ 1 lbk row matching 1 abcd company in 2 sectors outputs 2 rows", {
+  sector_abcd <- c("automotive", "shipping")
 
   lbk <- tibble(
     id_direct_loantaker = "C196",
@@ -60,25 +58,24 @@ test_that("w/ 1 lbk row matching 1 ald company in 2 sectors outputs 2 rows", {
     name_ultimate_parent = NA_character_,
   )
 
-  ald <- tibble(
+  abcd <- tibble(
     name_company = "suzuki motor corp",
-    sector = sector_ald,
-    alias_ald = "suzukimotor corp",
+    sector = sector_abcd
   )
 
-  out <- match_name(lbk, ald, by_sector = FALSE)
+  out <- match_name(lbk, abcd, by_sector = FALSE)
   expect_equal(nrow(out), 2L)
   out$sector
-  expect_equal(out$sector_ald, sector_ald)
+  expect_equal(out$sector_abcd, sector_abcd)
 })
 
 test_that("`by_sector = TRUE` yields only matching sectors", {
   out <- match_name(
     fake_lbk(),
-    fake_ald(),
+    fake_abcd(),
     by_sector = TRUE
   ) %>%
-    filter(sector != sector_ald)
+    filter(sector != sector_abcd)
 
   expect_equal(nrow(out), 0L)
 })
@@ -92,7 +89,7 @@ test_that("w/ mismatching sector_classification and `by_sector = TRUE` yields
   expect_warning(
     out <- match_name(
       fake_lbk(sector_classification_direct_loantaker = code_for_sector_power),
-      fake_ald(sector = sector_not_power),
+      fake_abcd(sector = sector_not_power),
       by_sector = TRUE
     ),
     "no match"
@@ -111,9 +108,9 @@ test_that("w/ row 1 of loanbook and crucial cols yields expected", {
     id_2dii = "UP1",
     level = "ultimate_parent",
     sector = "power",
-    sector_ald = "power",
+    sector_abcd = "power",
     name = "Alpine Knits India Pvt. Limited",
-    name_ald = "alpine knits india pvt. limited",
+    name_abcd = "alpine knits india pvt. limited",
     score = 1,
     source = "loanbook",
     borderline = TRUE
@@ -122,25 +119,25 @@ test_that("w/ row 1 of loanbook and crucial cols yields expected", {
   if (packageVersion("r2dii.data") > "0.1.4") expected$borderline <- FALSE
 
   expect_equal(
-    match_name(fake_lbk(), fake_ald()),
+    match_name(fake_lbk(), fake_abcd()),
     expected
   )
 })
 
 test_that("w/ 1 row of full loanbook_demo yields expected names", {
-  out <- match_name(slice(loanbook_demo, 1L), fake_ald())
+  out <- match_name(slice(loanbook_demo, 1L), fake_abcd())
   expect_equal(names(out), expect_names_match_name)
 })
 
-test_that("takes unprepared loanbook and ald datasets", {
-  expect_no_error(match_name(slice(loanbook_demo, 1), ald_demo))
+test_that("takes unprepared loanbook and abcd datasets", {
+  expect_no_error(match_name(slice(loanbook_demo, 1), abcd_demo))
 })
 
 test_that("w/ loanbook that matches nothing, yields expected", {
   # Matches zero row ...
   lbk2 <- slice(loanbook_demo, 2)
   expect_warning(
-    out <- match_name(lbk2, ald_demo),
+    out <- match_name(lbk2, abcd_demo),
     "no match"
   )
   expect_equal(nrow(out), 0L)
@@ -149,14 +146,14 @@ test_that("w/ loanbook that matches nothing, yields expected", {
     names(out),
     expect_names_match_name
   )
-  expect_false(any(c("alias", "alias_ald") %in% names(out)))
+  expect_false(any(c("alias", "alias_abcd") %in% names(out)))
 })
 
-test_that("w/ 2 lbk rows matching 2 ald rows, yields expected names", {
+test_that("w/ 2 lbk rows matching 2 abcd rows, yields expected names", {
   # Slice 5 once was problematic (#85)
   lbk45 <- slice(loanbook_demo, 4:5)
   expect_named(
-    match_name(lbk45, ald_demo),
+    match_name(lbk45, abcd_demo),
     expect_names_match_name
   )
 })
@@ -165,22 +162,22 @@ test_that("w/ 1 lbk row matching ultimate, yields expected names", {
   lbk1 <- slice(loanbook_demo, 1)
 
   expect_named(
-    match_name(lbk1, ald_demo),
+    match_name(lbk1, abcd_demo),
     expect_names_match_name
   )
 })
 
 test_that("takes `min_score`", {
   expect_no_error(
-    match_name(slice(loanbook_demo, 1), ald_demo, min_score = 0.5)
+    match_name(slice(loanbook_demo, 1), abcd_demo, min_score = 0.5)
   )
 })
 
 test_that("takes `method`", {
   expect_false(
     identical(
-      match_name(slice(loanbook_demo, 4:15), ald_demo, method = "jw"),
-      match_name(slice(loanbook_demo, 4:15), ald_demo, method = "osa")
+      match_name(slice(loanbook_demo, 4:15), abcd_demo, method = "jw"),
+      match_name(slice(loanbook_demo, 4:15), abcd_demo, method = "osa")
     )
   )
 })
@@ -190,8 +187,8 @@ test_that("takes `p`", {
 
   expect_false(
     identical(
-      match_name(lbk45, ald_demo, p = 0.1),
-      match_name(lbk45, ald_demo, p = 0.2)
+      match_name(lbk45, abcd_demo, p = 0.1),
+      match_name(lbk45, abcd_demo, p = 0.2)
     )
   )
 })
@@ -201,44 +198,44 @@ test_that("takes `overwrite`", {
 
   expect_false(
     identical(
-      match_name(lbk, ald_demo, overwrite = NULL),
-      suppressWarnings(match_name(lbk, ald_demo, overwrite = overwrite_demo))
+      match_name(lbk, abcd_demo, overwrite = NULL),
+      suppressWarnings(match_name(lbk, abcd_demo, overwrite = overwrite_demo))
     )
   )
 })
 
 test_that("warns overwrite", {
   expect_warning(
-    match_name(fake_lbk(), fake_ald(), overwrite = overwrite_demo)
+    match_name(fake_lbk(), fake_abcd(), overwrite = overwrite_demo)
   )
 
   expect_snapshot(
-    match_name(fake_lbk(), fake_ald(), overwrite = overwrite_demo)
+    match_name(fake_lbk(), fake_abcd(), overwrite = overwrite_demo)
   )
 })
 
 test_that("recovers `sector_lbk`", {
   expect_true(
     rlang::has_name(
-      match_name(slice(loanbook_demo, 1), ald_demo),
+      match_name(slice(loanbook_demo, 1), abcd_demo),
       "sector"
     )
   )
 })
 
-test_that("recovers `sector_ald`", {
+test_that("recovers `sector_abcd`", {
   expect_true(
-    rlang::has_name(match_name(loanbook_demo, ald_demo), "sector_ald")
+    rlang::has_name(match_name(loanbook_demo, abcd_demo), "sector_abcd")
   )
 })
 
 test_that("outputs name from loanbook, not name.y (bug fix)", {
-  out <- match_name(slice(loanbook_demo, 1), ald_demo)
+  out <- match_name(slice(loanbook_demo, 1), abcd_demo)
   expect_false(has_name(out, "name.y"))
 })
 
 test_that("works with `min_score = 0` (bug fix)", {
-  expect_no_error(match_name(slice(loanbook_demo, 1), ald_demo, min_score = 0))
+  expect_no_error(match_name(slice(loanbook_demo, 1), abcd_demo, min_score = 0))
 })
 
 test_that("outputs only perfect matches if any (#40 @2diiKlaus)", {
@@ -248,7 +245,7 @@ test_that("outputs only perfect matches if any (#40 @2diiKlaus)", {
     filter(name_direct_loantaker == this_name)
 
   nanimo_scores <- this_lbk %>%
-    match_name(ald_demo) %>%
+    match_name(abcd_demo) %>%
     mutate(alias = to_alias(name)) %>%
     filter(alias == this_alias) %>%
     pull(score)
@@ -262,7 +259,7 @@ test_that("outputs only perfect matches if any (#40 @2diiKlaus)", {
 })
 
 test_that("match_name()$level lacks prefix 'name_' suffix '_lbk'", {
-  out <- match_name(slice(loanbook_demo, 1), ald_demo)
+  out <- match_name(slice(loanbook_demo, 1), abcd_demo)
   expect_false(
     any(startsWith(unique(out$level), "name_"))
   )
@@ -275,17 +272,17 @@ test_that("preserves groups", {
   grouped_loanbook <- slice(loanbook_demo, 1) %>%
     group_by(id_loan)
 
-  expect_true(is_grouped_df(match_name(grouped_loanbook, ald_demo)))
+  expect_true(is_grouped_df(match_name(grouped_loanbook, abcd_demo)))
 })
 
 test_that("outputs id consistent with level", {
-  out <- slice(loanbook_demo, 5) %>% match_name(ald_demo)
+  out <- slice(loanbook_demo, 5) %>% match_name(abcd_demo)
   expect_equal(out$level, c("direct_loantaker", "ultimate_parent"))
   expect_equal(out$id_2dii, c("DL1", "UP1"))
 })
 
 test_that("no longer yiels all NAs in lbk columns (#85 @jdhoffa)", {
-  out <- match_name(loanbook_demo, ald_demo)
+  out <- match_name(loanbook_demo, abcd_demo)
   out_lbk_cols <- out %>%
     select(
       setdiff(
@@ -322,7 +319,7 @@ test_that("handles any number of intermediate_parent columns (#84)", {
     sector_classification_direct_loantaker = 3511
   )
 
-  out <- match_name(lbk_mini, fake_ald())
+  out <- match_name(lbk_mini, fake_abcd())
   output_levels <- unique(out$level)
   expect_length(output_levels, 5L)
 
@@ -335,14 +332,14 @@ test_that("warns/errors if some/all system classification is unknown", {
 
   expect_warning(
     class = "some_sec_classif_unknown",
-    match_name(some_bad_system, fake_ald())
+    match_name(some_bad_system, fake_abcd())
   )
 
   all_bad_system <- fake_lbk(sector_classification_system = c("bad", "bad"))
 
   expect_error(
     class = "all_sec_classif_unknown",
-    match_name(all_bad_system, fake_ald())
+    match_name(all_bad_system, fake_abcd())
   )
 
   bad <- -999
@@ -352,7 +349,7 @@ test_that("warns/errors if some/all system classification is unknown", {
     # In this expectation, we only care about this specific warning
     expect_warning(
       class = "some_sec_classif_unknown",
-      match_name(some_bad_code, fake_ald())
+      match_name(some_bad_code, fake_abcd())
     )
   )
 
@@ -360,23 +357,23 @@ test_that("warns/errors if some/all system classification is unknown", {
 
   expect_error(
     class = "all_sec_classif_unknown",
-    match_name(all_bad_code, fake_ald()),
+    match_name(all_bad_code, fake_abcd()),
   )
 })
 
 # crucial names -----------------------------------------------------------
 
-test_that("w/ loanbook or ald with missing names errors gracefully", {
+test_that("w/ loanbook or abcd with missing names errors gracefully", {
   invalid <- function(data, x) dplyr::rename(data, bad = all_of_(x))
 
-  expect_error_missing_names <- function(lbk = NULL, ald = NULL) {
+  expect_error_missing_names <- function(lbk = NULL, abcd = NULL) {
     expect_error(
       class = "missing_names",
-      match_name(lbk %||% fake_lbk(), ald %||% fake_ald())
+      match_name(lbk %||% fake_lbk(), abcd %||% fake_abcd())
     )
   }
 
-  expect_error_missing_names(ald = invalid(fake_ald(), "sector"))
+  expect_error_missing_names(abcd = invalid(fake_abcd(), "sector"))
 
   expect_error_missing_names(invalid(fake_lbk(), "name_ultimate_parent"))
   expect_error_missing_names(invalid(fake_lbk(), "id_ultimate_parent"))
@@ -394,7 +391,7 @@ test_that("w/ loanbook or ald with missing names errors gracefully", {
     match_name(
       # missing name_intermediate_parent (doesn't come with fake_lbk())
       fake_lbk(id_intermediate_parent = id_direct_loantaker),
-      fake_ald()
+      fake_abcd()
     )
   )
 })
@@ -405,7 +402,7 @@ test_that("w/ lbk with name_intermediate_* but missing id_intermediate_*", {
       class = "has_name_but_not_id",
       # missing id_intermediate_parent (doesn't come with fake_lbk())
       fake_lbk(name_intermediate_parent = name_direct_loantaker),
-      fake_ald()
+      fake_abcd()
     )
   )
 })
@@ -416,7 +413,7 @@ test_that("w/ overwrite with missing names errors gracefully", {
     match_name(
       fake_lbk(),
       overwrite = tibble(bad = 1),
-      fake_ald()
+      fake_abcd()
     )
   )
 })
@@ -425,19 +422,19 @@ test_that("with bad input errors gracefully", {
   bad_loanbook <- loanbook_demo %>%
     mutate(name_direct_loantaker = as.numeric(12))
 
-  expect_no_error(match_name(bad_loanbook, ald_demo))
+  expect_no_error(match_name(bad_loanbook, abcd_demo))
 })
 
 test_that("with name_intermediate but not id_intermediate throws an error", {
   expect_error(
     class = "has_name_but_not_id",
-    match_name(fake_lbk(name_intermediate_parent = "a"), fake_ald())
+    match_name(fake_lbk(name_intermediate_parent = "a"), fake_abcd())
   )
 })
 
 test_that("0-row output has expected column type", {
   lbk <- slice(loanbook_demo, 2)
-  out <- expect_warning(match_name(lbk, ald_demo), "no match")
+  out <- expect_warning(match_name(lbk, abcd_demo), "no match")
 
   lbk_types <- purrr::map_chr(lbk, typeof)
   out_types <- purrr::map_chr(out, typeof)
@@ -448,7 +445,7 @@ test_that("0-row output has expected column type", {
 
 test_that("works with UP266", {
   up266 <- filter(loanbook_demo, id_ultimate_parent == "UP266")
-  out <- match_name(up266, ald_demo)
+  out <- match_name(up266, abcd_demo)
 
   prefix <- c(glue("id_{level()}"), glue("name_{level()}"))
   prefix <- paste0(prefix, collapse = "|")
@@ -456,9 +453,9 @@ test_that("works with UP266", {
   expect_snapshot(select(out, .data$id_2dii, matches(prefix)))
 })
 
-test_that("with loanbook_demo and ald_demo outputs expected value", {
+test_that("with loanbook_demo and abcd_demo outputs expected value", {
   skip_on_ci()
-  out <- match_name(loanbook_demo, ald_demo)
+  out <- match_name(loanbook_demo, abcd_demo)
   expect_snapshot_value(round_dbl(out), style = "json2")
 })
 
@@ -470,7 +467,7 @@ test_that("w/ mismatching sector_classification and `by_sector = FALSE` yields
 
   out <- match_name(
     fake_lbk(sector_classification_direct_loantaker = code_for_sector_power),
-    fake_ald(sector = sector_not_power),
+    fake_abcd(sector = sector_not_power),
     by_sector = FALSE
   )
   expect_equal(nrow(out), 1L)
@@ -479,14 +476,14 @@ test_that("w/ mismatching sector_classification and `by_sector = FALSE` yields
 test_that("takes `by_sector`", {
   expect_false(
     identical(
-      match_name(slice(loanbook_demo, 4:15), ald_demo, by_sector = TRUE),
-      match_name(slice(loanbook_demo, 4:15), ald_demo, by_sector = FALSE)
+      match_name(slice(loanbook_demo, 4:15), abcd_demo, by_sector = TRUE),
+      match_name(slice(loanbook_demo, 4:15), abcd_demo, by_sector = FALSE)
     )
   )
 })
 
-test_that("w/ duplicates in ald throws now error; instead remove duplicates", {
-  dupl <- rbind(fake_ald(), fake_ald())
+test_that("w/ duplicates in abcd throws now error; instead remove duplicates", {
+  dupl <- rbind(fake_abcd(), fake_abcd())
   expect_error(out <- match_name(fake_lbk(), dupl), NA)
   expect_equal(nrow(out), 1L)
 })
@@ -495,35 +492,35 @@ test_that("throws an error if the `loanbook` has reserved columns", {
   alias <- mutate(fake_lbk(), alias = "bla")
   expect_error(
     class = "reserved_column",
-    match_name(alias, fake_ald()),
+    match_name(alias, fake_abcd()),
     regexp = "alias"
   )
 
   sector <- mutate(fake_lbk(), sector = "auto")
   expect_error(
     class = "reserved_column",
-    match_name(sector, fake_ald()),
+    match_name(sector, fake_abcd()),
     regexp = "sector"
   )
 
   rowid <- mutate(fake_lbk(), rowid = 1L)
   expect_error(
     class = "reserved_column",
-    match_name(rowid, fake_ald()),
+    match_name(rowid, fake_abcd()),
     regexp = "rowid"
   )
 
   rowid_sector <- mutate(fake_lbk(), rowid = 1L, sector = "auto")
   expect_error(
     class = "reserved_column",
-    match_name(rowid_sector, fake_ald()),
+    match_name(rowid_sector, fake_abcd()),
     regexp = "rowid.*sector"
   )
 
   sector_rowid <- mutate(fake_lbk(), sector = "auto", rowid = 1L)
   expect_error(
     class = "reserved_column",
-    match_name(sector_rowid, fake_ald()),
+    match_name(sector_rowid, fake_abcd()),
     regexp = "rowid.*sector"
   )
 })
@@ -550,20 +547,20 @@ test_that("outputs correct `borderline` (#269)", {
     sector_classification_direct_loantaker = c(border_false, border_true)
   )
 
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     name_company = some_companies,
     sector = c(coal_2dii, power_2dii)
   )
 
-  out <- match_name(lbk, ald)
+  out <- match_name(lbk, abcd)
   expect_equal(out$borderline, c(FALSE, TRUE))
 })
 
-test_that("matches any case of ald$sector, but converts sector to lowercase", {
-  low <- match_name(fake_lbk(), fake_ald(sector = "power"))
+test_that("matches any case of abcd$sector, but converts sector to lowercase", {
+  low <- match_name(fake_lbk(), fake_abcd(sector = "power"))
   expect_equal(low$sector, "power")
 
-  upp <- match_name(fake_lbk(), fake_ald(sector = "POWER"))
+  upp <- match_name(fake_lbk(), fake_abcd(sector = "POWER"))
   # The original uppercase is converted to lowercase
   expect_equal(upp$sector, "power")
 
@@ -571,15 +568,15 @@ test_that("matches any case of ald$sector, but converts sector to lowercase", {
   expect_identical(low, upp)
 })
 
-test_that("matches any case of ald$name_company, but preserves original case", {
-  low <- match_name(fake_lbk(), fake_ald(name_company = "alpine knits"))
+test_that("matches any case of abcd$name_company, but preserves original case", {
+  low <- match_name(fake_lbk(), fake_abcd(name_company = "alpine knits"))
   expect_equal(nrow(low), 1L)
-  expect_equal(low$name_ald, "alpine knits")
+  expect_equal(low$name_abcd, "alpine knits")
 
-  upp <- match_name(fake_lbk(), fake_ald(name_company = "ALPINE KNITS"))
+  upp <- match_name(fake_lbk(), fake_abcd(name_company = "ALPINE KNITS"))
   expect_equal(nrow(upp), 1L)
   # The original uppercase is preserved
-  expect_equal(upp$name_ald, "ALPINE KNITS")
+  expect_equal(upp$name_abcd, "ALPINE KNITS")
 })
 
 test_that("with arguments passed via ellipsis, throws no error (#310)", {
@@ -587,36 +584,36 @@ test_that("with arguments passed via ellipsis, throws no error (#310)", {
   expect_false(any(grepl("^q$", names(formals(match_name)))))
 
   # `q` should pass `...` with no error
-  expect_no_error(match_name(fake_lbk(), fake_ald(), method = "qgram", q = 1))
+  expect_no_error(match_name(fake_lbk(), fake_abcd(), method = "qgram", q = 1))
 })
 
 test_that("with arguments passed via ellipsis, outputs the expected score", {
   lbk <-
     fake_lbk(name_direct_loantaker = "Yuamen Changyuan Hydropower Co., Ltd.")
-  ald <-
-    fake_ald(name_company = "yiyang baoyuan power generation co., ltd.")
+  abcd <-
+    fake_abcd(name_company = "yiyang baoyuan power generation co., ltd.")
 
   this_q <- 0.5
   expected1 <- stringdist::stringsim(
     to_alias(lbk$name_direct_loantaker),
-    to_alias(ald$name_company),
+    to_alias(abcd$name_company),
     method = "qgram", q = this_q
   )
 
-  out1 <- match_name(lbk, ald, method = "qgram", q = this_q)
+  out1 <- match_name(lbk, abcd, method = "qgram", q = this_q)
   expect_equal(unique(out1$score), expected1)
 
   this_q <- 1
   expected2 <- stringdist::stringsim(
     to_alias(lbk$name_direct_loantaker),
-    to_alias(ald$name_company),
+    to_alias(abcd$name_company),
     method = "qgram", q = this_q
   )
 
   # Ensure this test does not just duplicate the previous one
   expect_false(identical(expected1, expected2))
 
-  out2 <- match_name(lbk, ald, method = "qgram", q = this_q)
+  out2 <- match_name(lbk, abcd, method = "qgram", q = this_q)
   expect_equal(unique(out2$score), expected2)
 })
 
@@ -627,7 +624,7 @@ test_that("with relevant options allows loanbook with reserved columns", {
   lbk <- mutate(fake_lbk(), sector = "a", borderline = FALSE)
   expect_no_error(
     # Don't warn if found no match
-    suppressWarnings(match_name(lbk, fake_ald()))
+    suppressWarnings(match_name(lbk, fake_abcd()))
   )
 })
 
@@ -636,7 +633,7 @@ test_that("w/ loanbook w/ reserved cols, outputs sector not i.sector (#330)", {
   on.exit(options(restore), add = TRUE)
 
   reserved <- mutate(fake_lbk(), sector = "power", borderline = FALSE)
-  out <- match_name(reserved, fake_ald())
+  out <- match_name(reserved, fake_abcd())
 
   expect_true(utils::hasName(out, "sector"))
   expect_false(utils::hasName(out, "i.sector"))
@@ -648,13 +645,13 @@ test_that("w/ loanbook lacking sector or borderline, errors gracefully (#330)",
 
   lacks_borderline <- mutate(fake_lbk(), sector = "power")
   expect_error(
-    match_name(lacks_borderline, fake_ald()),
+    match_name(lacks_borderline, fake_abcd()),
     "Must have both `sector` and `borderline`"
   )
 
   lacks_sector <- mutate(fake_lbk(), borderline = TRUE)
   expect_error(
-    match_name(lacks_sector, fake_ald()),
+    match_name(lacks_sector, fake_abcd()),
     "Must have both `sector` and `borderline`"
   )
 })
@@ -662,15 +659,15 @@ test_that("w/ loanbook lacking sector or borderline, errors gracefully (#330)",
 test_that("errors if any id_loan is duplicated (#349)", {
   duplicated <- rep.int(1, times = 2)
   lbk <- fake_lbk(id_loan = duplicated)
-  ald <- fake_ald()
+  abcd <- fake_abcd()
 
-  expect_snapshot_error(match_name(lbk, ald))
-  expect_error(class = "duplicated_id_loan", match_name(lbk, ald))
+  expect_snapshot_error(match_name(lbk, abcd))
+  expect_error(class = "duplicated_id_loan", match_name(lbk, abcd))
 })
 
 test_that("allows custom `sector_classifications` via options() (#354)", {
   loanbook <- fake_lbk(sector_classification_system = "XYZ")
-  ald <- fake_ald()
+  abcd <- fake_abcd()
   custom_classification <- tibble::tribble(
     ~sector,       ~borderline,  ~code, ~code_system,
     "power",             FALSE, "3511",        "XYZ",
@@ -678,7 +675,7 @@ test_that("allows custom `sector_classifications` via options() (#354)", {
 
   # Allow users to inject their own `sector_classifications`
   old <- options(r2dii.match.sector_classifications = custom_classification)
-  out <- match_name(loanbook, ald)
+  out <- match_name(loanbook, abcd)
   expect_equal(nrow(out), 1L)
   options(old)
 })
